
import java.io.*;
import java.sql.*;
import java.util.*;
//import java.awt.*;

/*
 *
 * This class provides a representation of a Shoe
 *
 */
public class Shoe {

	// data members
	private String name;
	private String brand;
	private String type;
	private String style;
	private double price;
	private double size;
	private int qty;
	private static final char underscore = '_';
	private static final char space = ' ';

	// constructor
	public Shoe( String name, String brand, String type, String style,
				 double price, double size, int qty ) {

		this.name = name;
		this.brand = brand;
		this.type = type;
		this.style = style;
		this.price = price;
		this.size = size;
		this.qty = qty;

	}

	// accessor methods
	public String getName ( ) { return name;  }
	public String getBrand( ) { return brand; }
	public String getType ( ) { return type;  }
	public String getStyle( ) { return style; }
	public double getPrice( ) { return price; }
	public double getSize ( ) { return size;  }
	public int    getQty  ( ) { return qty;   }


	// mutator methods
	public void setQty( int newQty ) { qty = newQty; }
	public void incrQty( )           { qty++; }
	public void decrQty( )           { qty--; }

	// equals to compare two shoe objects
	public boolean equals( Shoe compareShoe ) {

		return( compareShoe.name.equals ( this.name  ) &&
				compareShoe.brand.equals( this.brand ) &&
				compareShoe.type.equals ( this.type  ) &&
				compareShoe.style.equals( this.style ) &&
				compareShoe.price  ==     this.price   &&
				compareShoe.size   ==     this.size  );
	}

	// toString with default delimiter of '#'
	public String toString( ) {

		return( name  + "#" +
				brand + "#" +
				type  + "#" +
				style + "#" +
				price + "#" +
				size  + "#" +
				qty   + "#" );
	}

	// toString with variable delimiter
	public String toString( String delimiter ) {

		return( name  + delimiter +
				brand + delimiter +
				type  + delimiter +
				style + delimiter +
				price + delimiter +
				size  + delimiter +
				qty   + delimiter );
	}

	// convStringToShoe:
	public static Shoe convertStringToShoe( String shoeStr, String delimiter ) {

		StringTokenizer st = new StringTokenizer( shoeStr, delimiter );
		String name = st.nextToken();
		String brand = (st.nextToken()).replace( underscore, space);
		String type = st.nextToken();
		String style = (st.nextToken()).replace( underscore, space);
		double price = Double.parseDouble( st.nextToken() );
		double size = Double.parseDouble( st.nextToken() );
		int qty = Integer.parseInt( st.nextToken() );

		return( new Shoe( name, brand, type, style, price, size, qty ) );

	}

	public static Vector readShoesFromFile( String filename ) throws IOException {

		Vector shoes = new Vector();

		File inFile = new File( filename );
		BufferedReader cin = new BufferedReader( new FileReader( inFile ) );

		while( cin.ready() ) {
			shoes.addElement( convertStringToShoe( cin.readLine(), "\t" ) );
		}

		return( shoes );

	} // end readShoesFromFile method

} // end class Shoe