import java.io.*;
import java.sql.*;
import java.util.*;
import java.awt.*;

/*
 *
 * This java application handles adding stuff to the cart.
 * It first reads the content of a file name "cart" in the
 * current directory and outputs them, before appending the
 * passed item at the bottom of the form.
 *
 */
public class UpdateDB {

    private static Vector shoes;
	private static String first;
	private static String last;
	private static String addr;
	private static String city;
	private static String state;
	private static String zip;

	// extracts customer data from parameter
	private static void extractCustomerData( String custString ) {

		StringTokenizer st = new StringTokenizer( custString, "&" );

		// extract first name
		first = st.nextToken();
		first = first.substring( first.indexOf('=') + 1, first.length() );
		first = convPlusToSpace( first );

		// extract last name
		last = st.nextToken();
		last = last.substring( last.indexOf('=') + 1, last.length() );
		last = convPlusToSpace( last );

		// extract address
		addr = st.nextToken();
		addr = addr.substring( addr.indexOf('=') + 1, addr.length() );
		addr = convPlusToSpace( addr );

		// extract city
		city = st.nextToken();
		city = city.substring( city.indexOf('=') + 1, city.length() );
		city = convPlusToSpace( city );

		// extract state
		state = st.nextToken();
		state = state.substring( state.indexOf('=') + 1, state.length() );
		state = convPlusToSpace( state );

		// extract zip
		zip = st.nextToken();
		zip = zip.substring( zip.indexOf('=') + 1, zip.length() );
		zip = convPlusToSpace( zip );

	}

	// converts any '+' characters in a string to space ' ' characters
	private static String convPlusToSpace( String str ) {

		StringBuffer strBuf = new StringBuffer( "" );
		for(int i = 0; i < str.length(); i++ ){
			char c = str.charAt( i );
			if( c == '+' )
				strBuf.append(' ');
			else
				strBuf.append( c );
		}
		return( strBuf.toString() );
	}


	// empties the file cart, but does not delete the file
	private static void emptyCart() throws IOException {
		File cart = new File("cart");
		PrintWriter pw = new PrintWriter( new BufferedWriter ( new FileWriter ( cart ) ) );
		pw.close();
	}


    public static void main(String[] args) throws IOException {

		// extract customer data from arguments
		extractCustomerData( args[0] );

		String sqlExprGetCustID = new String(	"SELECT custID FROM customer " +
												"WHERE first_name=\"" + first + "\"" +
											  	"AND last_name=\"" + last + "\"" +
											  	"AND street=\"" + addr + "\"" +
											  	"AND city=\"" + city + "\"" +
												"AND state=\"" + state + "\"" +
												"AND zip=\"" + zip + "\"" );

		if( (DBConnect.execSQLquery( sqlExprGetCustID, 1 )).length() == 0 ) {

			// get this customer's new id
			int newCustID;

			// customer not currently in db; assign customer the next available customer ID
			String sqlExprGetMaxID = new String( "SELECT MAX(custID) FROM customer;" );
			try {
				newCustID = 1 + Integer.parseInt( DBConnect.execSQLquery( sqlExprGetMaxID, 1 ) );
			}
			// this only happens if NO customers are currently in the db (first ID will be 1)
			catch( NumberFormatException nfe ) {
				newCustID = 1;
			}

			// add customer to database
			String sqlExprInsertCust = new String( "INSERT customer VALUES (\"" +
					newCustID + "\",\"" + first + "\",\"" + last + "\",\"" + addr + "\",\"" +
					city + "\",\"" + state + "\",\"" + zip + "\");" );
			DBConnect.execSQLquery( sqlExprInsertCust );
		}


		// get shoes from file
		shoes = Shoe.readShoesFromFile( "cart" );

		// loop through shoes updating quantities
		for( int i = 0; i < shoes.size(); i++ ) {

			// the shoe to have quantities adjusted
			Shoe shoe = (Shoe)(shoes.elementAt(i));

			// the quantity to be removed from the database
			int qtyRemoved = shoe.getQty();

			// obtain the current quantity in the db for this shoe
			int curQty;
			String sqlExprGetQty = new String( "SELECT qty FROM size_qty " +
						"WHERE name = \"" + shoe.getName() + "\" AND size = \"" +
						shoe.getSize() + "\";" );
			try {
				curQty = Integer.parseInt( DBConnect.execSQLquery( sqlExprGetQty, 1 ) );
			}
			// this exception shouldn't happen, but if it does, just set curQty to 0.
			catch( NumberFormatException nfe ) {
				curQty = 0;
			}

			// perform the update
			String sqlExprUpdateQty = new String( "UPDATE size_qty SET qty = \"" +
					(curQty - qtyRemoved) + "\" WHERE name = \"" + shoe.getName() +
					"\" AND size = \"" + shoe.getSize() + "\";" );
			DBConnect.execSQLquery( sqlExprUpdateQty );

		}

		emptyCart();
		buildPage();


	} // end main




	private static void buildPage() {

		String font5 = "<font face=\"Bauhaus 93\" color=\"#008000\" size=\"5\">";

		System.out.println( "Content-type: text/html\n\n" );
	    System.out.println( "<html>" );
	    System.out.println( "<body>" );
		System.out.println( "<table align=\"center\" width=\"100%\" cellpadding=\"6\">" );

	// banner
		System.out.println( "<tr align=\"center\">" );
		System.out.println( "<td colspan=\"2\">" );
		System.out.println( "<i><img src=\"shoepic1.bmp\" width=\"100\" height=\"100\"></i>" );
		System.out.println( "<i><img src=\"E-Shoe1.gif\"  width=\"300\" height=\"100\"></i>" );
		System.out.println( "<i><img src=\"shoepic2.bmp\" width=\"100\" height=\"100\"></i>" );
		System.out.println( "</td>" );
		System.out.println( "</tr>" );

	// first thick line
		System.out.println( "<tr align=\"center\">" );
		System.out.println( "<td colspan=\"2\">" );
		System.out.println( "<i><img src=\"line30.gif\"  width=\"100%\"></i>" );
		System.out.println( "</td>" );
		System.out.println( "</tr>" );

	// thank you message
		System.out.println( "<tr>" );
		System.out.println( "<td width=\"30%\">" );
		System.out.println( "<p align=\"center\">" + font5 + "Transaction completed successfully.</font></p>" );
		System.out.println( "<p align=\"center\">" + font5 + "Thanks for shopping with E-ShoeStore.</font></p>" );
		System.out.println( "</td>" );
		System.out.println( "</tr>" );

	    System.out.println( "</table>");
	    System.out.println( "</body>");
	    System.out.println( "</html>");

    } // end buildPage


}
